summaryrefslogtreecommitdiffstats
path: root/lanbrowsing/lisa/netmanager.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lanbrowsing/lisa/netmanager.cpp')
-rw-r--r--lanbrowsing/lisa/netmanager.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/lanbrowsing/lisa/netmanager.cpp b/lanbrowsing/lisa/netmanager.cpp
index 46002ed1..e652ce97 100644
--- a/lanbrowsing/lisa/netmanager.cpp
+++ b/lanbrowsing/lisa/netmanager.cpp
@@ -142,11 +142,11 @@ void NetManager::configure(Config& config)
MyString netAddressStr=tmp.left(tmp.find('/'));
tmp=tmp.mid(tmp.find('/')+1);
tmp=tmp.left(tmp.find(';'));
- mdcerr<<"NetManager::readConfig: broadcastNet "<<netAddressStr<<" with tqmask "<<tmp<<std::endl;
+ mdcerr<<"NetManager::readConfig: broadcastNet "<<netAddressStr<<" with mask "<<tmp<<std::endl;
int netMask=inet_addr(tmp.c_str());
int netAddress=inet_addr(netAddressStr.c_str());
m_broadcastAddress= netAddress | (~netMask);
- mdcerr<<"NetManager::readConfig: net "<<std::ios::hex<<netAddress<<" with tqmask "<<netMask<<" gives "<<m_broadcastAddress<<std::endl;
+ mdcerr<<"NetManager::readConfig: net "<<std::ios::hex<<netAddress<<" with mask "<<netMask<<" gives "<<m_broadcastAddress<<std::endl;
//maybe this way we can avoid that all servers on the net send
//their requests synchronously, since now the refreshtime isn't
@@ -602,7 +602,7 @@ void NetManager::scan()
}
else if (pid!=0)
{
- //tqparent
+ //parent
::close(fileDescr[1]);
m_pipeFD=fileDescr[0];
m_childPid=pid;
@@ -617,7 +617,7 @@ void NetManager::scan()
doScan();
//in the child we don't have to call setServerServer()
//since this opens the listening socket, what has to be done
//in the tqparent process
m_serverServer=1;
}
else
@@ -629,7 +629,7 @@ void NetManager::scan()
doScan();
//in the child we don't have to call setServerServer()
//since this opens the listening socket, what has to be done
//in the tqparent process
m_serverServer=1;
}
else
@@ -639,7 +639,7 @@ void NetManager::scan()
m_serverServer=0;
}
}
- mdcerr<<" NetScanner::scan: sending information to tqparent process"<<std::endl;
+ mdcerr<<" NetScanner::scan: sending information to parent process"<<std::endl;
writeDataToFD(fileDescr[1],m_serverServer);
mdcerr<<" NetScanner::scan: closed FD: "<<::close(fileDescr[1])<<std::endl;
mdcerr<<" NetScanner::scan: exiting now"<<std::endl;
@@ -617,7 +617,7 @@ void NetManager::scan()
//in the child we don't have to call setServerServer()
//since this opens the listening socket, what has to be done
- //in the tqparent process
+ //in the parent process
m_serverServer=1;
}
@@ -629,7 +629,7 @@ void NetManager::scan()
//in the child we don't have to call setServerServer()
//since this opens the listening socket, what has to be done
- //in the tqparent process
+ //in the parent process
m_serverServer=1;
}